#
# spec file for package mame
#
# Copyright (c) 2014 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define upstream_version %(printf '%%ss\\n' '%version' | tr -d . )

Name:           mame
Version:        0.160
Release:        1.4
Summary:        Versatile Arcade Machine Emulator
License:        MAME-License and BSD-3-Clause
Group:          System/Emulators/Other
Url:            http://mamedev.org/
BuildRequires:  gcc-c++
# BFD ld requires > 2GB RAM during build
BuildRequires:  alsa-devel
BuildRequires:  binutils-gold
BuildRequires:  dos2unix
BuildRequires:  flac-devel
BuildRequires:  libexpat-devel
BuildRequires:  libjpeg8-devel
BuildRequires:  unzip
%if 0%{?suse_version} < 1230
# for openSUSE < 12.3 libqt4-x11 depends on libjpeg62 while mame depends on
# libjpeg8, so build the old GTK2 debugger instead
BuildRequires:  gconf2-devel
BuildRequires:  gtk2-devel
%else
BuildRequires:  libqt4-devel
%endif
BuildRequires:  Mesa-devel
BuildRequires:  libSDL2-devel
BuildRequires:  libSDL2_ttf-devel
BuildRequires:  portmidi-devel
BuildRequires:  xorg-x11-devel
BuildRequires:  zlib-devel
Source0:        http://mamedev.org/downloader.php?file=releases/mame%{upstream_version}.zip
Source1:        mame.ini.in
Source2:        mess.ini.in
# PATCH-FIX-OPENSUSE mame-fix-executable-suffix.patch gber@opensuse.org -- Do not add a suffix for 64bit builds
Patch0:         mame-fix-executable-suffix.patch
Patch1:         mame_makefile_armv7_no_pipe.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
MAME is an arcade machine emulator covering a broad spectrum of hardware
ranging from the very earliest CPU-based systems to much more modern 3D
platforms.  In conjuntion with ROM and CHD images "dumped" from arcade games'
original circuit-board ROM chips, hard disks, and CD-ROMs which are not
included in this package it allows you to play thousands of arcade video games.

%package tools
Summary:        Tools for MAME
Group:          System/Emulators/Other
Requires:       %{name} = %{version}-%{release}

%description tools
This package contains tools for MAME.

%package -n mess
Summary:        Emulator of Multiple Computer and Console Systems
Group:          System/Emulators/Other

%description -n mess
MESS emulates the hardware of numerous computer and console systems on a PC. It
can currently emulate over 250 systems from the last 5 decades and it strives
for accuracy and portability above all else.

%package -n mess-tools
Summary:        Tools for MESS
Group:          System/Emulators/Other
Requires:       mess = %{version}-%{release}

%description -n mess-tools
This package contains tools for MESS.

%prep
%setup -q -c
unzip -qq mame.zip
# convert lineendings
find . -type f -print0 | xargs -0 dos2unix || :

%patch0 -p1

%ifarch armv7l armv7hl
%patch1 -p1
%endif

sed -e "s,@DATADIR@,%{_datadir},g"\
       -e "s,@SYSCONFDIR@,%{_sysconfdir},g" %SOURCE1 >mame.ini
sed -e "s,@DATADIR@,%{_datadir},g"\
       -e "s,@SYSCONFDIR@,%{_sysconfdir},g" %SOURCE2 >mess.ini

# use date of last changelog entry instead of __DATE__ macro
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{_sourcedir}/%{name}.changes")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
sed -i "s/__DATE__/${DATE}/g" src/version.c

%build
%if 0%{?suse_version} < 1310
mkdir gcc
ln -s /usr/bin/gold ./gcc/ld
GOLD_FLAG="-B${PWD}/gcc"
%else
GOLD_FLAG="-fuse-ld=gold"
%endif
make %{?_smp_mflags} \
    BUILD_EXPAT=0 \
    BUILD_ZLIB=0 \
    BUILD_FLAC=0 \
    BUILD_JPEGLIB=0 \
    BUILD_MIDILIB=0 \
%if 0%{?suse_version} < 1230
    NO_USE_QTDEBUG=1 \
%endif
    SYMBOLS=1 \
    SYMLEVEL=2 \
    DUMPSYM= \
    PROFILE= \
    VERBOSE=1 \
    SANITIZE= \
    OPTIMIZE=0 \
    NOWERROR=1 \
    AR="%{__ar}" \
    CC="%{__cc}" \
    LD="%{__cxx} ${GOLD_FLAG}" \
    RM="%{__rm} -f" \
    OPT_FLAGS="%{optflags} -fno-strict-aliasing -DINI_PATH='\"%{_sysconfdir}/mame;\"' ${GOLD_FLAG}" \
    FULLNAME="mame" \
    TARGET="mame" \
    SUBTARGET="mame" \
    all
rm -rf obj
make %{?_smp_mflags} \
    BUILD_EXPAT=0 \
    BUILD_ZLIB=0 \
    BUILD_FLAC=0 \
    BUILD_JPEGLIB=0 \
    BUILD_MIDILIB=0 \
%if 0%{?suse_version} < 1230
    NO_USE_QTDEBUG=1 \
%endif
    SYMBOLS=1 \
    SYMLEVEL=2 \
    DUMPSYM= \
    PROFILE= \
    VERBOSE=1 \
    SANITIZE= \
    OPTIMIZE=0 \
    NOWERROR=1 \
    AR="%{__ar}" \
    CC="%{__cc}" \
    LD="%{__cxx} ${GOLD_FLAG}" \
    RM="%{__rm} -f" \
    OPT_FLAGS="%{optflags} -fno-strict-aliasing -DINI_PATH='\"%{_sysconfdir}/mess;\"' ${GOLD_FLAG}" \
    FULLNAME="mess" \
    TARGET="mess" \
    SUBTARGET="mess" \
    all

%install
for mame_data_dir in artwork chds cheats crosshair ctrlr effects fonts keymaps \
        roms samples; do
    install -d -m 755 %{buildroot}%{_datadir}/mame/$mame_data_dir
done
install -D -m 644 mame.ini %{buildroot}%{_sysconfdir}/mame/mame.ini
install -D -m 755 mame %{buildroot}%{_bindir}/mame
install -m 755 chdman jedutil ldresample ldverify romcmp unidasm \
        %{buildroot}%{_bindir}
for mame_tool in regrep srcclean src2html split testkeys; do
    install -m 755 $mame_tool %{buildroot}%{_bindir}/mame-$mame_tool
done
install -d -m 755 %{buildroot}%{_mandir}/man6
install -d -m 755 %{buildroot}%{_mandir}/man1
pushd src/osd/sdl/man/
sed 's/testkeys/mame-testkeys/g' testkeys.1 >mame-testkeys.1
install -m 644 chdman.1 jedutil.1 ldverify.1 mame-testkeys.1 romcmp.1 \
        %{buildroot}%{_mandir}/man1
install -m 644 mame.6 %{buildroot}%{_mandir}/man6
popd

install -D -m 644 mess.ini %{buildroot}%{_sysconfdir}/mess/mess.ini
install -D -m 755 mess %{buildroot}%{_bindir}/mess
for mess_tool in imgtool castool floptool; do
    install -m 755 $mess_tool %{buildroot}%{_bindir}/mess-$mess_tool
done
for mess_data_dir in artwork hash keymaps; do
    install -d -m 755 %{buildroot}%{_datadir}/mess/$mess_data_dir
done
install -m 644 artwork/*.png %{buildroot}%{_datadir}/mess/artwork
install -m 644 hash/*.xml %{buildroot}%{_datadir}/mess/hash
install -m 644 src/osd/sdl/keymaps/*.txt %{buildroot}%{_datadir}/mess/keymaps
install -m 644 src/osd/sdl/man/mess.6 %{buildroot}%{_mandir}/man6/mess.6
pushd src/osd/sdl/man/
for mess_tool in imgtool castool floptool; do
    sed "s/${mess_tool}/mess\\-${mess_tool}/g" ${mess_tool}.1 >mess-${mess_tool}.1
    install -m 644 mess-${mess_tool}.1 %{buildroot}%{_mandir}/man1/mess-${mess_tool}.1
done
popd

%clean
rm -rf "%{buildroot}"

%files
%defattr(-,root,root,-)
%doc whatsnew*.txt docs/
%doc %{_mandir}/man6/mame.6*
%dir %{_sysconfdir}/mame
%config(noreplace) %{_sysconfdir}/mame/mame.ini
%dir %{_datadir}/mame/
%{_datadir}/mame/
%{_bindir}/mame

%files tools
%defattr(-,root,root,-)
%doc %{_mandir}/man1/chdman.1*
%doc %{_mandir}/man1/jedutil.1*
%doc %{_mandir}/man1/ldverify.1*
%doc %{_mandir}/man1/mame-testkeys.1*
%doc %{_mandir}/man1/romcmp.1*
%{_bindir}/chdman
%{_bindir}/jedutil
%{_bindir}/ldresample
%{_bindir}/ldverify
%{_bindir}/mame-regrep
%{_bindir}/mame-srcclean
%{_bindir}/mame-src2html
%{_bindir}/mame-split
%{_bindir}/mame-testkeys
%{_bindir}/romcmp
%{_bindir}/unidasm

%files -n mess
%defattr(-,root,root,-)
%doc messnew.txt docs/license.txt
%doc %{_mandir}/man6/mess.6*
%dir %{_sysconfdir}/mess
%config(noreplace) %{_sysconfdir}/mess/mess.ini
%{_bindir}/mess
%{_datadir}/mess/

%files -n mess-tools
%defattr(-,root,root,-)
%{_bindir}/mess-imgtool
%{_bindir}/mess-castool
%{_bindir}/mess-floptool
%{_mandir}/man1/mess-imgtool.1*
%{_mandir}/man1/mess-castool.1*
%{_mandir}/man1/mess-floptool.1*

%changelog
* Sun May 17 2015 gber@opensuse.org
- update to version 0.160
  * new games:
    + Cute Fighter
    + Su Ho Seong
    + Star Trek (Sidam, Head On hardware)
    + Endless Riches
    + Pop'n Music 3 (ver JA-A)
    + Come Back Toto
    + NBA Jam Extreme
    + Final Fight Revenge
    + Player's Edge Plus (PS0366) Double Diamond Deluxe Slots
    + Player's Edge Plus (PS0372) Double Diamond Deluxe Slots
    + Player's Edge Plus (PS0373) Double Diamond Deluxe Slots
    + PuzzLove
    + Player's Edge Plus (PS0090) Gold, Silver & Bronze Slots
    + Poke Champ (set 2)
    + Super MIss World
    + Player's Edge Plus (X002111P+XP000038) 4 of a Kind Bonus
    Poker (with Seq Royal Flush)
    + Crazy Bonus 2002
    + Castle Of Dracula
    + New Cherry Gold '99 (bootleg of Super Cherry Master) (set 1)
    + Spider
    + Brick Zone (v1.1, Spinner)
  * new clones:
    + Super Breakout (Canyon and Vertical Breakout, prototype)
    + Cadash (Japan, version 2)
    + Cadash (Japan, oldest version)
    + Billiard Academy Real Break (Europe, older)
    + Sauro (Recreativos Real S.A. license)
    + Dunk Shot (Rev C, FD1089A 317-0022)
    + Atari Tetris (bootleg set 3)
    + Fire Trap (US, set 2)
    + Play Girls 2 (bootleg)
    + Ave Fenix (Recreativos Franco)
    + Oriental Legend 2 (V101, China)
    + Knights of Valour 2 New Legend (V300, Taiwan)
    + Magic Bubble (Adult version, YS-0211 PCB)
    + Battle Bakraid - Unlimited Version (China) (Tue Jun 8 1999)
    + Vigilante (World, Rev E)
    + Dragon World II (ver. 100H, Hong Kong
    + Player's Edge Plus (X002173P+XP000038) Ace$ Bonus Poker
    + Player's Edge Plus (PP0040) Standard Draw Poker
    (International)
    + Player's Edge Plus (PP0042) 10's or Better
    + Player's Edge Plus (PP0043) 10's or Better (International,
    set 2)
    + Player's Edge Plus (PP0060) Standard Draw Poker (set 3)
    + Player's Edge Plus (PP0429) Joker Poker (Aces or Better, set
    2)
    + Player's Edge Plus (IVC006) Clear EEPROM Chip
    + Player's Edge Plus (Set004) Set Chip
    + Player's Edge Plus (KE0017) Keno
    + Player's Choice (MG0252) Multi-Game
    + JT-104
    + Arkanoid Returns (Ver 2.02A 1997/02/10)
    + Donkey Kong (Spanish Crazy Kong bootleg)
    + Galaxy Monsters (Laguna S.A. Spanish bootleg of Space
    Invaders)
    + Botanic (English / Spanish)
    + Club Kart (Rev C)
    + Windjammer (021216)
    + Tron (Germany)
    + S.V.G. - Spectral vs Generation (M68k label V101TW) (ARM
    label V101TW, ROM 06/20/05 S.V.G V100)
    + Darius (US)
    + Raiden 2 (Switzerland)
    + Star Wars (set 3)
    + Mortal Kombat (Yawdim bootleg, set 3)
    + Brick Blast (bootleg of Wall Crash)
    + D-Day (Dooyong) (Korea)
    + Yam Yam (Korea)
    + Space Duel (version 1)
    + Space Duel (prototype)
    + Montana Choice (MG0183) Multi-Game
    + Player's Edge Plus (X002478P+XP000154) Joker Poker - French
    + Player's Edge Plus (X002479P+XP000154) Joker Poker - French
    + Player's Edge Plus (X002478P+XP000154) Joker Poker (Aces or
    Better) - French
    + Player's Edge Plus (X002485P+XP000154) Standard Draw Poker -
    French
    + Guilty Gear XX #Reload (GDL-0019)
    + Melty Blood Act Cadenza (GDL-0028)
    + Ridge Racer V Arcade Battle (RRV2 Ver. A)
    + Atari Football II
    + Super Street Fighter II Turbo (Asia 940223 Phoenix Edition)
    (bootleg)
    + F1 Exhaust Note (Japan)
    + Radikal Bikers (Version 2.02)
    + Dharma Doujou (World)
    + Dominos 4 (Cocktail)
    + Super Breakout (Cocktail, prototype)
    + Over Drive (set 2)
    + Over Drive (set 3)
    + Dungeons & Dragons: Shadow over Mystara (Asia 960208)
    + Black Widow (prototype)
    + Player's Edge Plus (PP0038) Standard Draw Poker
    + Player's Edge Plus (PP0116) Standard Draw Poker (Mirage)
    + Adventure Quiz Capcom World 2 (Japan 920611, B-Board
    90629B-3, no   battery)
    + Ghost Squad (GDX-0012)
    + Sega Network Taisen Mahjong MJ 2 (Rev F) (GDX-0006F)
    + Side Arms - Hyper Dyne (US, 861202)
    + Turbo Out Run (Japan, deluxe cockpit, FD1094 317-0101)
    + The Key Of Avalon: The Wizard Master (server) (Rev E)
    + The Key Of Avalon: The Wizard Master (server) (Rev F)
    + The Key Of Avalon: The Wizard Master (server) (Rev G)
    + The Key Of Avalon: The Wizard Master (client) (Rev E)
    + The Key Of Avalon: The Wizard Master (client) (Rev F)
    + The Key Of Avalon: The Wizard Master (client) (Rev G)
    + The Key Of Avalon 1.20 - Summon The New Monsters (server)
    (Rev A)
    + The Key Of Avalon 1.20 - Summon The New Monsters (client)
    (Rev A)
    + The Key Of Avalon 1.30 - Chaotic Sabbat (server) (Rev C)
    + Gekitou Pro Yakyuu Mizushima Shinji All Stars vs. Pro Yakyuu
    (Rev B)
    + Asura Buster - Eternal Warriors (Japan) (ARCADIA review
    build)
    + Super Spacefortress Macross II / Chou-Jikuu Yousai Macross II
    (GAMEST review build)
    + Ultra X Weapons / Ultra Keibitai (GAMEST review build)
    + Nitro Ball (World, set 2)
    + Brick Zone (v6.0, Joystick)
    + New Cherry Gold '99 (bootleg of Super Cherry Master) (set 2)
    + Super Cherry Gold (bootleg of Super Cherry Master)
    + Grand Cherry Master (bootleg of Super Cherry Master)
    + Chouji Meikyuu Legion (Japan ver 1.05)
    + Boot Camp (set 2)
    + Frogger (videotron bootleg)
    + Player's Edge Plus (PP0158) 4 of a Kind Bonus Poker (set 5)
    + Player's Edge Plus (PP0190) Deuces Wild Poker (set 1)
    + Player's Edge Plus (PP0203) 4 of a Kind Bonus Poker (set 4)
    + Player's Edge Plus (PP0515) Double Bonus Poker (set 3)
    + Player's Edge Plus (BE0014) Blackjack (International
    English/Spanish)
    + Player's Edge Plus (X000006P+XP000038) Standard Draw Poker
    + Player's Edge Plus (X000042P+XP000038) 10's or Better
    + Player's Edge Plus (X000764P+XP000038) 4 of a Kind Bonus
    Poker
    + Player's Edge Plus (X002010P+XP000038) Nevada Bonus Poker
    + Player's Edge Plus (X002016P+XP000038) Full House Bonus Poker
    + Player's Edge Plus (X002017P+XP000038) Full House Bonus Poker
    + Player's Edge Plus (X002037P+XP000038) Nevada Bonus Poker
    + Player's Edge Plus (X002039P+XP000038) Nevada Bonus Poker
    + Player's Edge Plus (X002247P+XP000038) Standard Draw Poker
    + Player's Edge Plus (X002386P+XP000038) 4 of a Kind Bonus
    Poker
    + Puzznic (bootleg)
    + Mahjong Electromagnetic Base
    + Battle K-Road (Korean PCB)
    + Adventure Quiz Capcom World 2 (Japan 920611, B-Board
    91634B-2)
    + Willow (World)
    + The Combatribes (US, older)
    + Raiden II (France)
    + Golden Axe II (Mega Play) (original rev)
    + Daioh (location test version)
    + Thunder Deity Biography (Chinese hack of Battle Garegga)
* Thu Jan  1 2015 p.seiler@linuxmail.org
- added patch to build against arm successfully
* Tue Nov  4 2014 gber@opensuse.org
- update to version 0.155
  * new games:
    + Music Ball
    + Dongfang Shenlong
    + Bobble Bobble (set 2)
    + Jump Jump
    + Elfin
    + Raiden 2
    + Raiden DX
    + Raiden II New / Raiden DX (newer V33 PCB) (2 sets, different
    EEPROM for each game)
    + New Zero Team / Zero Team 2000
    + Go-Stop
    + Player's Edge (PK1024) Aces and Faces Poker
    + Americana (9131-00)
    + Gundam Wing: Endless Duel (SNES bootleg)
    + Vegas 1 (Ver 2.3 dual coin pulse, shorter)
    + Vegas 1 (Ver 2.1 dual coin pulse, longer)
    + Vegas 1 (Ver 1.33 single coin pulse)
    + Merit Touch Joker Poker (9132-00)
    + Black Velvet
    + Camel Lights
    + Foxy Lady
    + Real
    + Rio
    + Chuck-a-luck
    + Family Fun
    + Star Trip
    + Vegas
    + Sharp Shooter
    + Old Coney Island
    + Pinball Lizard
    + Super Nova
    + Sharp Shooter II
    + Global Warfare
    + Attila the Hun
    + Agents 777
    + Captain Hook
    + Lady Sharpshooter
    + Rotation VIII (v. 1.01)
    + Rotation VIII (v. 1.15)
    + Pinball
    + Stingray
    + Stars
    + Memory Lane
    + Lectronamo
    + Wildfyre
    + Nugent
    + Dracula
    + Trident
    + Hot Hand
    + Magic
    + Cosmic Princess
    + Freedom
    + Night Rider
    + Black Jack
    + Evel Knievel
    + Mata Hari
    + Eight Ball
    + Power Play
    + Strikes and Spares
    + Super Picker
    + Roy Clark - The Entertainer
    + Thunderbolt
    + Hoe Down
    + Take Five
    + Hearts & Spades
    + Flame of Athens
    + Disco '79
    + Eros One
    + Circa 1933
    + Star Shooter
    + FJ Holden
    + Orbit 1
    + Shark
    + Howzat!
    + The Empire Strikes Back
    + Atlantis
    + Black Hole
    + Heavy Metal
    + Taito Test Fixture
    + Shock
    + Oba Oba
    + Meteor
    + Sure Shot
    + Cosmic
    + Vortex
    + Rally
    + Speed Test
    + Drakor
    + Brave Team
    + Canasta 86
    + Lap by Lap
    + Moon Light
    + Clown
    + Atleta
    + Mundial 90
    + Corsario
    + 250CC
    + Faeton
    + Ski Jump
    + Space City
    + Strike
    + Odin
    + Odin De Luxe
    + Solar Wars
    + Pole Position
    + Star Wars
    + Wolf Man
    + Nemesis
    + Odisea Paris-Dakar
    + Flash
    + Tri-Zone
    + Time Warp
    + Stellar Wars
    + Laser Ball
    + Scorpion
    + Blackout
    + Gorgar
    + Algar
    + Alien Poker
    + Warlok
    + Laser Cue
    + Time Fantasy
    + Thunderball
    + Still Crazy
    + Black Knight
    + Cosmic Gunfighter
    + Pharaoh
    + Star Light
    + Jungle Lord
    + Firepower II
    + Varkon
    + Defender
    + Sorcerer
    + Space Shuttle
  * new clones:
    + Player's Edge Plus (X000124P+XP000053) Deuces Wild Poker
    + Player's Edge Plus (X002308P+XP000112) Triple Double Bonus
    Poker
    + Armored Warriors (Asia 941024)
    + Punch-Out!! (Rev B)
    + Super Punch-Out!! (Rev A)
    + F1 Exhaust Note (US)
    + Cops (UK)
    + Pac-Mania (111187 sound program)
    + Storm Blade (Japan)
    + Search Eye (English / Korean / Japanese / Spanish)
    + Sky Shark (US, set 2)
    + Growl (World, Rev 1)
    + Bonze Adventure (World, prototype)
    + Colorama (P521 V13, Spanish)
    + Viper Phase 1 (New Version, Holland)
    + Phoenix (D&L bootleg)
    + Wonder Boy III - Monster Lair (encrypted bootleg)
    + Shadow Dancer (bootleg, set 2)
    + 19XX: The War Against Destiny (Asia 960104)
    + Food Fight (rev 1)
    + Candory (Ponpoko bootleg with Mario)
    + Centipede (revision 1)
    + Air Rescue (Japan)
    + Gaplus (Tecfri PCB)
    + The Simpsons (2 Players World, set 3)
    + Fantasia (940803 PCB)
    + The X-Files
    + Vendetta (World, 2 Players, ver. unknown)
    + Hacha Mecha Fighter (19th Sep. 1991, unprotected, bootleg
    Thunder Dragon conversion)
    + Mega Man: The Power Battle (CPS2, USA 950926, SAMPLE Version)
    + Raiden DX (Japan)
    + Raiden DX (China, Ideal International Development Corp
    license)
    + Raiden II (US, set 2)
    + Raiden II (easy version, Germany)
    + Raiden II (harder, Raiden DX hardware)
    + Baryon - Future Assault (set 2)
    + Player's Edge Plus (PP0158) 4 of a Kind Bonus Poker (set 1)
    + Zero Hour (Inder) [Basilio García]
    + Initial D Arcade Stage (Japan)
    + Initial D Arcade Stage Ver. 2 (Japan)
    + Street Fighter II': Magic Delta Turbo (bootleg, set 4)
    + Street Fighter II': Champion Edition (M9, bootleg)
    + Street Fighter II: The World Warrior (TAB Austria, bootleg,
    set 3)
    + Street Fighter II: The World Warrior (TAB Austria, bootleg,
    set 4)
    + Oriental Legend / Xi You Shi E Zhuan (ver. 111, Taiwanese
    Board)
    + Arkanoid (Japan)
    + Chelnov - Atomic Runner (Japan, bootleg with I8031, set 1)
    + Chelnov - Atomic Runner (Japan, bootleg with I8031, set 2)
    + Shot Rider (bootleg)
    + Hexa (with 2xZ80, protected)
    + Jumping (set 2)
    + Pac-Man (JPM bootleg)
    + Speed Up (Version 1.00)
    + Frisky Tom (set 3, encrypted?)
    + Pengo (bootleg on JPM Pac-Man hardware)
    + Super Street Fighter II: The New Challengers (World 931005)
    + Frogger (bootleg on Amigo? hardware)
    + Come-Cocos (Ms. Pac-Man) ('Made in Greece' Triunvi bootleg)
    + Mario Bros. (Japan, bootleg) (different music/sfx)
* Mon Aug 25 2014 gber@opensuse.org
- update to version 0.154
  * new games
    + Wyvern F-0
    + Fireball
    + Pong Doubles
    + Coco Loco
    + Leader (version Z 2E, Greece)
    + Neraidoula (Fairy Butterfly)
    + LuckBoomH - Lucky Boom (Hard Times hardware)
    + Step Champ (GQ930 VER. JA)
    + Gallag Video Game / Petalouda (Butterfly, x50)
    + Juuouki (set 1, Japan, FD1094 317-0065)
    + Ming Xing 100 (Star 100)
    + Ken Sei Mogura - Street Fighter II (1994.04.18, Ver 1.00)
    + Super Masters Golf (World?, Floppy Based, FD1094
    317-0058-05d?)
    + Ace Attacker (FD1094 317-0059)
    + Super Pacman (v1.2) + Cherry Master (Corsica, v8.31)
    + Tetris + Cherry Master (Corsica, v8.01, set 1)
    + Royal Card (Italian, Dino 4 hardware, encrypted)
    + Rolling Crush (version 1.07.E - 1999/02/11)
    + Player's Edge Plus (X002272P+XP000055) Black Jack Bonus Poker
    + Player's Edge Plus (X002275P+XP000055) Black Jack Bonus Poker
    + Player's Edge Plus (PP0766 A5W-A6F) Standard Draw Poker
    + Player's Edge Plus (PP0801 A5W-A6F) 10's or Better
    + Player's Edge Plus (PP0802 A5W-A6F) Standard Draw Poker
    + Player's Edge Plus (PP0803 A5W-A6F) Joker Poker
    + Player's Edge Plus (PP0803 A50-A6N) Joker Poker
    + Player's Edge Plus (PP0804 A5W-A6F) Bonus Poker Deluxe
    + Player's Edge Plus (PP0806 A5W-A6F) Standard Draw Poker
    + Player's Edge Plus (PP0818 A5W-A6F) Joker Poker (Aces or
    Better)
    + Player's Edge Plus (PP0819 A5W-A6F) Bonus Poker Deluxe
    + Player's Edge Plus (PP0825 A59-A7C) White Hot Aces
    + Player's Edge Plus (XM00013P+XMP00025) Multi-Poker
    + Player's Edge Plus (PP0816) Treasure Chest Poker
  * new clones
    + Black Tiger / Black Dragon (mixed bootleg?)
    + Nemo (World 901109)
    + Spectrum 2000 (vertical)
    + Gun.Smoke (bootleg)
    + Fire Hawk (vertical)
    + Borench (set 2)
    + VS Mahjong Otome Ryouran (newer)
    + Snake Pit (9/14/84)
    + Sen Jing - Guardian Storm (Japan)
    + The Berlin Wall (Korea)
    + Pollux (NTC license)
    + Dragon Bowl (set 2, unencrypted program)
    + Tao Taido (2/3 button version)
    + Player's Edge Plus (PP0431) Deuces Joker Wild Poker
    (International)
    + Player's Edge Plus (PP0242) Deuces Wild Poker (International
    English/Spanish)
    + Player's Edge Plus (PP0288) Standard Draw Poker (Spanish)
    + Player's Edge Plus (PP0431) Deuces Joker Wild Poker
    + Player's Edge Plus (PP0449) Standard Draw Poker
    (International English/Spanish)
    + Player's Edge Plus (X000150P+XP000038) Standard Draw Poker
    + Player's Edge Plus (X000242P+XP000053) Deuces Wild Poker
    + Player's Edge Plus (X000516P+XP000038) Double Bonus Poker
    + Player's Edge Plus (X002038P+XP000038) Nevada Bonus Poker
    + Player's Edge Plus (X002044P+XP000038) Triple Bonus Poker
    + Player's Edge Plus (X002306P+XP000112) Triple Double Bonus
    Poker
    + Player's Edge Plus (X002310P+XP000112) Triple Double Bonus
    Poker
    + Player's Edge Plus (XMP00013) 5-in-1 Wingboard (CG2346) -
    Spanish
    + Player's Edge Plus (XMP00026) 5-in-1 Wingboard (CG2346) -
    Spanish
    + Player's Edge Plus (PP0009) Standard Draw Poker
    + Player's Edge Plus (PP0046) 10's or Better (International)
    + Player's Edge Plus (PP0063) 10's or Better
    + Player's Edge Plus (PP0127) Deuces Joker Wild Poker
    (International)
    + Player's Edge Plus (PP0171) Joker Poker (International)
    + Player's Edge Plus (PP0190) Deuces Wild Poker (International)
    + Player's Edge Plus (PP0197) Standard Draw Poker
    (International)
    + Player's Edge Plus (PP0203) 4 of a Kind Bonus Poker
    (International)
    + Player's Edge Plus (PP0516) Double Bonus Poker (International)
    + Player's Edge Plus (XM00009P+XMP00002) Multi-Poker
    + Player's Edge Plus (IP0028) Joker Poker - French
    + Player's Edge Plus (IP0029) Joker Poker - French
    + Player's Edge Plus (IP0031) Standard Draw Poker - French
    + Player's Edge Plus (IP0051) Joker Poker - French
    + Player's Edge Plus (IP0058) Standard Draw Poker - French
    + Player's Edge Plus (IP0062) Joker Poker - French
    + Player's Edge Plus (IP0101) Joker Poker - French
    + Player's Edge Plus (IP0103) Joker Poker - French
    + Player's Edge Plus (IP0105) Joker Poker - French
    + Player's Edge Plus (IP0108) Standard Draw Poker - French
    + Player's Edge Plus (IP0111) Joker Poker - French
    + Player's Edge Plus (IP0112) Standard Draw Poker - French
    + Player's Edge Plus (IP0112) Standard Draw Poker - French
    + Player's Edge Plus (IP0115) Joker Poker - French
    + Player's Edge Plus (IP0116) Standard Draw Poker - French
    + Player's Edge Plus (IP0118) Standard Draw Poker - French
    + Player's Edge Plus (IP0120) Standard Draw Poker - French
    + Player's Edge Plus (X002419P+XP000064) Deuces Wild Bonus
    Poker - French
    + Player's Edge Plus (X002421P+XP000064) Deuces Wild Bonus
    Poker - French
    + Player's Edge Plus (PP0043) 10's or Better (International)
    + Player's Edge Plus (PP0046) 10's or Better (set 2)
    + Player's Edge Plus (PP0265) 4 of a Kind Bonus Poker
    (International)
    + Player's Edge Plus (X002276P+XP000055) Black Jack Bonus Poker
    + Player's Edge Plus (X000550P+XP000055) Joker Poker (Two Pair
    or Better)
    + Crazy Cross
    + Bouncing Balls (Adult)
    + Maya (set 3)
    + Pleiads (Irecsa)
    + Gang Wars (Japan)
    + Pleiads (Spanish bootleg)
    + Quaaak (bootleg of Frogger)
    + Mystery Castle (alternate set)
    + Atari 4x4
    + Black Belt (Squawk and Talk)
    + Party Animal (German)
    + Strange Science (German)
    + Star Wars (1.04)
    + Baywatch (England)
    + Rotation VIII (v. 1.15)
    + Rotation VIII (v. 1.01)
    + Moon Light (Inder)
    + Halley Comet (alternate version)
    + F14 Tomcat (P-5)
    + Pin-Bot (P-4)
    + Still Crazy (L-1)
    + Apollo 13 (1.00)
    + Independence Day (v2.01)
    + Playboy (3.02)
    + Cactus Canyon (1.0)
    + Cactus Canyon (1.04 Test 0.2)
    + Congo (1.1)
    + Safe Cracker (0.91)
    + Judge Dredd (L-5)
    + Judge Dredd (L-4)
    + Star Trek: The Next Generation (P-8)
    + Star Trek: The Next Generation (P-4)
    + Star Trek: The Next Generation (LX-3)
    + The Getaway: High Speed II (P-B)
    + Corvette (LX2)
    + Corvette (LA1)
    + Johnny Mnemonic (0.5R)
    + No Fear: Dangerous Sports (1.0)
    + Terminator 3 (3.01) series
    + Simpsons Pinball party 3.00 series
    + Harley Davidson 1.03 (UK Only)
    + Zira
    + Meg-Aaton (alternate set)
    + Nautilus
    + The Raid
    + Star Fire (alternate set)
    + Flash Dragon
    + Skill Flight (Playmatic)
    + Bone Busters Inc. (French)
    + Pool Sharks (LA-5)
    + Flash (L-2)
    + HyperBall (L-2)
    + Joust (L-1)
    + Jungle Lord (L-1)
    + Thunderball (P-2)
    + Thunderball (P-3)
    + Popeye Saves The Earth (LA-4)
    + Indianapolis 500 (1.0R)
    + World Cup Soccer (La-2)
    + Joust 2 - Survival of the Fittest (revision 1)
    + Two Crude (US, set 2)
    + Tazz-Mania (bootleg on Galaxian hardware with Starfield)
    + Midnight Run: Road Fighters 2 (Asia v1.10)
    + Miss Pukman ('Made in Greece' bootleg)
    + Zero Time (Datamat)
    + Raiden Fighters (Evaluation Software For Show, Germany)
    + Knights of Valour Super Heroes / Sangoku Senki Super Heroes
    (ver. 100, CN)
    + Space Invaders (Electromar, Spanish)
    + Come-Cocos (Ms. Pac-Man) ('Made in Greece' bootleg)
    + Galaga '88 (02-03-88)
    + Peek-a-Boo! (US, ver 1.0)
    + 42 (hack of 1942)
    + SDI - Strategic Defense Initiative (Japan, old, System 16A,
    FD1089B 317-0027)
    + Tiger Road (US)
    + Center Court (prototype, MC-8123B)
    + Lunar Lander (screen test)
* Fri May  9 2014 gber@opensuse.org
- fix gold usage on < 13.1
- add missing dependency on X11 headers
* Thu May  8 2014 gber@opensuse.org
- update to version 0.153
  * new games
    + Top Blade V
    + Carket Ball
    + Mega Phoenix
    + Aaargh (Arcadia)
    + Happy 6-in-1 (ver. 101CN)
    + x2222 (prototype)
    + The Real Broadway
    + Mongolfier New (Italian)
    + Soccer New (Italian)
    + Player's Edge Plus (X002377P+XP000112) Super Double Bonus
    Poker
    + Player's Edge Plus (IP0041) Double Deuces Wild Poker - French
    + Player's Edge Plus (PS0426) Sizzling Sevens Slots
    + Player's Edge Plus (PP0060) Standard Draw Poker (set 2)
    + Player's Edge Plus (PP0159) Standard Draw Poker
    (International)
    + Player's Edge Plus (X000040P+XP000038) Standard Draw Poker
    + Player's Edge Plus (X000046P+XP000038) 10's or Better
    + Player's Edge Plus (X000053P+XP000038) Joker Poker
    + Player's Edge Plus (X000537P+XP000038) Standard Draw Poker
    + Player's Edge Plus (X000568P+XP000038) Joker Poker
    + Player's Edge Plus (X000588P+XP000038) Joker Poker
    + Player's Edge Plus (X002461P+XP000055) Joker Poker
    + Player's Edge Plus (PS0296) Haywire
    + Player's Edge Plus (PP0120) Wild Sevens Poker
    + Bingo
    + China Town (Ver 1B, Dino4 HW)
    + Luna Park (set 1, dual program)
    + Luna Park (set 2, dual program)
    + Luna Park (set 3)
    + Crystal Colours (CMC hardware)
    + Jubilee Double-Up Poker
    + Gold Fruit
    + Record (Version 1)
    + Cherry Wheel (Version 1.7)
    + MPU4 Reel Test (3.0)
    + Guns and Roses (C606191SMP, Australia)
    + Joker Poker (Coinmaster, Amusement Only)
    + Long Beach
    + The Gladiator / Road of the Sword / Shen Jian
    + Blastaball (Arcadia, V 2.1)
    + Pharaohs Match (Arcadia)
    + Delta Command (Arcadia)
    + Wave shark/Jet Wave
    + Puzzle Star (Sang Ho Soft)
    + Dancing Stage - Internet Ranking Ver (GC845 VER. EBA)
    + Player's Edge Plus (XM00007P+XMP00006) Multi-Poker
    + Player's Edge Plus (X000838S+XS000002) Five Times Pay Slots
    + Player's Edge Plus (X000841S+XS000002) Five Times Pay Slots
    + Player's Edge Plus (X001087S+XS000006) Double Double Diamond
    Slots
    + Player's Edge Plus (IP0079) Standard Draw Poker - French
    + Player's Edge Plus (X002420P+XP000064) Deuces Wild Bonus
    Poker - French
    + Power Kick
    + S.V.G. - Spectral vs Generation (M68k label V100JP)  (ARM
    label V100JP ROM 05/12/05  S.V.G V100) (Japan, JAMMA PCB)
  * new clones
    + Galaxian (Irem)
    + S.V.G. - Spectral vs Generation (M68k label V200) (ARM label
    V200, ROM 10/11/05 S.V.G V201)
    + Happy 6-in-1 (ver. 102CN)
    + Donkey Kong (hard kit)
    + Out Run (Japan, FD1089A 317-0019)
    + Cookie & Bibi (set 2)
    + Pocket Gals V.I.P (set 1)
    + Pocket Gals V.I.P (set 2)
    + Rough Ranger (v2.0)
    + Jet Wave (EAB, Euro v1.04)
    + Tekken 2 Ver.B (Japan, TES1/VER.B)
    + Tekken 2 Ver.B (Japan, TES1/VER.C)
    + Galaxia (sets 2,3,4)
    + Fantasia (940429 PCB, set 2)
    + Multi 5 / New Multi Game 5 (set 2)
    + Deluxe 5 (set 2 + set 3)
    + Gals Panic 3 (Hong Kong)
    + Viper Phase 1 (New Version, Korea)
    + Fantasy Zone (prototype)
    + Yukiwo (World, prototype)
    + Flying Tiger (set 2)
    + Puckman Pockimon (set 3)
    + Gulf War II (set 2)
    + Vs. Tennis (Set 3)
    + Spider-man: the Videogame (Japan)
    + Racing Beat (Japan)
    + Fighter's History (Japan ver 41-04, DE-0380-1 PCB)
    + Title Fight (Japan)
    + Disco Boy (Promat license?)
    + Miss World '96 (Nude) (2 sets)
    + Flak Attack (Japan, PWB 450593 sub-board)
    + Dancing Eyes (US, DC3/VER.C)
    + Mr. Driller (US, DRI3/VER.A2)
    + Oh! Bakyuuun (Japan, OB1/VER.A)
    + Funky Jet (World, rev 1)
    + Gulf Storm (set 3)
    + Street Fighter III: New Generation (Asia 970204, NO CD, bios
    set 1)
    + Super Toffy
    + 19XX: The War Against Destiny (Japan 960104, yellow case)
    + Zero Wing (2P set)
    + The Three Stooges In Brides Is Brides (set 2)
    + Billard List
    + Street Fighter III: New Generation (Asia 970204)
    + Shanghai 3 (World)
    + Shanghai (World)
    + Lethal Enforcers (ver UAB, 09/01/92 11:12)
    + Chase H.Q. (Japan, upright?)
    + Kero Kero Keroppi's Let's Play Together (USA, Version 2.0)
    + Air Assault (World)
    + Snow Bros. 2 - With New Elves / Otenki Paradise (bootleg)
    + Street Fighter II': Champion Edition (L735 Test Rom, bootleg)
    + Street Fighter II': Magic Delta Turbo (bootleg, set 3)
    + Trojan (bootleg)
    + Astro Combat (unencrypted bootleg)
    + Video Hustler (bootleg, set 2)
    + Intrepid (2 bootlegs)
    + Galaxian (bootleg, set 3)
    + Block Carnival / Thunder & Lightning 2 (bootleg)
    + Mouse Trap (bootleg)
    + Arch Rivals (rev 2.0 5/03/89, 8-way Joystick bootleg)
    + Hunchback (Scramble hardware, bootleg)
    + Ms. Pac-Man (bootleg on Crush Roller Hardware)
    + Galaxian Growing Galaxip / Galaxian Nave Creciente
    (Recreativos Franco S.A. Spanish bootleg)
    + Player's Edge Plus (PP0059) Two Pair or Better
    + Player's Edge Plus (PP0060) Standard Draw Poker
    + Player's Edge Plus (PP0219) Standard Draw Poker
    + Player's Edge Plus (PP0221) Standard Draw Poker (set 2)
    + Player's Edge Plus (PP0725) Double Bonus Poker (set 2)
    + Player's Edge Plus (PP0010) Standard Draw Poker
    + Player's Edge Plus (PP0014) Standard Draw Poker (Multi
    Region)
    + Player's Edge Plus (PP0040) Standard Draw Poker
    + Player's Edge Plus (PP0041) Standard Draw Poker
    + Player's Edge Plus (PP0053) Joker Poker
    + Player's Edge Plus (PP0057) Deuces Wild Poker
    + Player's Edge Plus (PP0158) 4 of a Kind Bonus Poker (set 2)
    + Player's Edge Plus (PP0203) 4 of a Kind Bonus Poker (set 3)
    + Player's Edge Plus (PP0265) 4 of a Kind Bonus Poker (set 2)
    + Player's Edge Plus (PP0510) Standard Draw Poker
    + Player's Edge Plus (PP0514) Double Bonus Poker (set 3)
    + Player's Edge Plus (PP0531) Joker Poker
    + Player's Edge Plus (PP0713) Bonus Poker Deluxe
    + Player's Edge Plus (X002283P+XP000057) Deuces Wild Bonus
    Poker
    + Player's Edge Plus (X002284P+XP000057) Deuces Wild Bonus
    Poker
    + Player's Edge Plus (X000224P+XP000053) Deuces Wild Poker
    + Player's Edge Plus (X000265P+XP000038) 4 of a Kind Bonus
    Poker
    + Player's Edge Plus (XM00008P+XMP00006) Multi-Poker
    + Player's Edge Plus (X000536P+XP000038) Joker Poker
    + Player's Edge Plus (X002440P+XP000053) Deuces Wild Poker
    + Player's Edge Plus (XM00006P+XMP00006) Multi-Poker
    + Player's Edge Plus (XMP00030) 5-in-1 Wingboard (CG2426)
    + Player's Edge Plus (PP0008) Standard Draw Poker
    + Player's Edge Plus (PP0014) Standard Draw Poker
    + Player's Edge Plus (PP0023) 10's or Better
    + Player's Edge Plus (PP0051) Joker Poker
    + Player's Edge Plus (PP0055) Deuces Wild Poker (set 3)
    + Player's Edge Plus (PP0057) Deuces Wild Poker (set 2)
    + Player's Edge Plus (PP0059) Two Pair or Better (set 2)
    + Player's Edge Plus (PP0064) Joker Poker
    + Player's Edge Plus (PP0083) 10's or Better
    + Player's Edge Plus (PP0116) Standard Draw Poker
    + Player's Edge Plus (PP0118) Standard Draw Poker
    + Player's Edge Plus (PP0125) Deuces Wild Poker
    + Player's Edge Plus (PP0158) 4 of a Kind Bonus Poker (set 3)
    + Player's Edge Plus (PP0249) Deuces Wild Poker
    + Pool 10 (Italian, set 5)
    + Pool 10 (Italian, set 6)
    + Pool 10 (Italian, set 7)
    + Pool 10 (Italian, set 8)
    + Royal (Pool 10 hack)
    + Royal Card (Austrian, set 7)
    + Royal Card (Austrian, set 7, CMC C1030 HW)
    + Royal Card (French)
    + Jolly Card (Italian, different colors, set 1)
    + Jolly Card (Italian, different colors, set 2)
    + Cherry Bonus III (set 3)
    + Cherry Bonus III (set 4, encrypted bootleg)
    + Videotron Poker (cards selector, set 2)
    + Witch (With ranking)
    + Tesorone Dell'Isola (Italy, v2.30)
    + Manic Panic Ghosts!
    + Scramble (Recreativos Franco, Spanish bootleg)
    + The Gladiator / Road of the Sword / Shen Jian (M68k label
    V100)  (ARM label V101, ROM 03/13/03 SHEN JIAN)
    + Super Chase - Criminal Termination (1992/10/26 20:24:29 CHASE
    3 VER 1.1, prototype)
    + Brick Zone (v1.1)
    + Cadash (World, prototype)
    + 1942 (prototype?)
    + 4 En Raya (set 2)
    + Gallop Racer (English Ver 10.17.K)
    + Chase Bombers (prototype)
    + The First Funky Fighter (set 2)
    + Cobra Command (Data East LD, set 2)
    + Spy Hunter (prototype)
    + U.N. Defense Force: Earth Joker (Japan, prototype?)
    + Syvalion (World, prototype)
    + Donkey Kong Junior (P kit)
    + Who Dunit (version 9.0)
    + Commando (US set 2)
    + Bucky O'Hare (ver EA)
    + Player's Edge Plus (PP0055) Deuces Wild Poker (set 2)
    + Player's Edge Plus (PP0171) Joker Poker
    + Player's Edge Plus (X000054P+XP000038) Deuces Wild Poker
    + Player's Edge Plus (PP0002) Standard Draw Poker
    + Player's Edge Plus (PP0045) 10's or Better
    + Player's Edge Plus (PP0455) Joker Poker
    + Player's Edge Plus (PP0458) Joker Poker
    + Player's Edge Plus (PP0536) Joker Poker
    + Player's Edge Plus (PP0726) Double Bonus Poker
    + Player's Edge Plus (IP0074) Joker Poker - French
    + Player's Edge Plus (X000045P+XP000038) 10's or Better
    + Player's Edge Plus (XMP00017) 5-in-1 Wingboard (CG2426)
    + Player's Edge Plus (PP0417) Deuces Wild Poker (set 2)
    + Player's Edge Plus (PP0002) Standard Draw Poker (set 2)
    + Player's Edge Plus (XMP00017) 5-in-1 Wingboard (CG2352)
    + Player's Edge Plus (PP0046) 10's or Better
    + Player's Edge Plus (X000002P+XP000038) Standard Draw Poker
    + Player's Edge Plus (X000060P+XP000038) Standard Draw Poker
    + Player's Edge Plus (X000171P+XP000038) Joker Poker
    + Player's Edge Plus (X000417P+XP000053) Deuces Wild Poker
    + Player's Edge Plus (X000459P+XP000038) Joker Poker
    + Player's Edge Plus (X002043P+XP000038) Triple Bonus Poker
    + Player's Edge Plus (X002066P+XP000038) Double Double Bonus
    Poker
    + Player's Edge Plus (X002121P+XP000037) Standard Draw Poker
    + Player's Edge Plus (X002150P+XP000038) 4 of a Kind Bonus
    Poker
    + Player's Edge Plus (X002180P+XP000038) Double Bonus Poker
    + Touchmaster 4000 (v6.03 New Jersey)
    + Touchmaster 4000 (v6.01 Minnesota)
    + Touchmaster 5000 (v7.10 Minnesota)
    + Touchmaster 7000 (v8.05 New Jersey)
    + Touchmaster 7000 (v8.04 Minnesota)
    + Touchmaster 7000 (v8.00 Minnesota)
    + World Kicks (WK3 Ver. A)
    + Wivern Wings
    + Invasion - The Abductors (version 3.0)
    + Street Fighter III: New Generation (Euro 970204)
- use gold linker in order to reduce memory consumption during
  build
* Tue Dec 17 2013 gber@opensuse.org
- update to version 0.151
  * new games
    + Dolmen
    + Frantic Fred
    + Player's Edge Plus (Set001) Set Chip
    + Player's Edge Plus (PP0103) Deuces Wild Poker
    + Player's Edge Plus (PP0127) Deuces Joker Wild Poker
    + Player's Edge Plus (PP0434) Bonus Poker Deluxe
    + Player's Edge Plus (PP0452) Double Deuces Wild Poker
    + Player's Edge Plus (PP0508) Loose Deuce Deuces Wild! Poker
    + Player's Edge Plus (PP0542) One Eyed Jacks Wild Poker
    + Player's Edge Plus (X002031P+XP000112) Lucky Deal Poker
    + Player's Edge Plus (X002040P+XP000038) Nevada Bonus Poker
    + Player's Edge Plus (X002042P+XP000038) Triple Bonus Poker
    + Player's Edge Plus (X002067P+XP000038) Double Double Bonus
    Poker
    + Player's Edge Plus (X002250P+XP000050) Shockwave Poker
    + Player's Edge Plus (X002307P+XP000112) Triple Double Bonus
    Poker
    + Player's Edge Plus (X002314P+XP000112) Triple Bonus Poker
    Plus
    + Player's Edge Plus (XMP00002+XM00004P) Multi-Poker
    + Player's Edge Plus (XMP00004+XM00005P) Multi-Poker
    + Space Invaders (SV version rev 1)
    + Turret Tower
    + Burger Time (set 3)
  * new clones
    + Erotictac/Tactic (set 2)
    + Super Derby (v.10.04)
    + After Burner II (German)
    + Various Player's Edge Plus Poker sets (100+)
    + Safari Rally (World)
    + Street Fighter II: The World Warrior (World 910318)
    + Strike Fighter (World)
    + Bomber Man World (Japan)
    + Final Fight (Japan 900613)
    + X-Men Vs. Street Fighter (Asia 961004)
    + Fire Shark (earlier)
    + Emergency Call Ambulance (US location test?)
    + Dynamite Dux (set 2, Japan, FD1094 317-0094)
    + E-Swat - Cyber Police (set 1, Japan, FD1094 317-0131)
    + Phozon (Sidam)
    + Space Invaders (SV version rev 1)
    + Space Invaders (SV version rev 2)
    + Kizuna Encounter - Super Tag Battle 4 Way Battle Version /
    Fu'un Super Tag Battle Special Version
* Thu Sep 26 2013 gber@opensuse.org
- update to version 0.150
  * new games
    + Casanova
    + Double Wings
    + Puzzli 2
    + Puzzli 2 Super
    + Panic Road
    + Poka Poka Satan
    + Touchstar Bonanza
    + Midnight Landing (Germany)
    + Super Game Mega Type 1
    + Tap a Tune
    + Wonder Boy III - Monster Lair (set 5, System 16A, FD1089A
    317-0086)
    + Desert Dan
    + Super Shanghai Dragon's Eye (Japan)
    + Pit Boss Superstar III 30
    + Sea Battle
    + Hidden Catch 2000 (AT89c52 protected)
  * new clones
    + Grand Striker (Japan)
    + Mechanized Attack (Japan)
    + Cyberbots: Fullmetal Madness (Japan 950424) (decrypted bootleg)
    + Knights of Valour Super Heroes Plus / Sangoku Senki Super
    Heroes Plus (ver. 101)
    + Night Slashers (US Rev 1.2, HuC6280 Sound CPU)
    + Cosmic Guerilla (Spanish bootleg)
    + Dungeons & Dragons: Tower of Doom (Asia 940412)
    + Street Fighter II: The World Warrior (Japan 920312)
    + Street Fighter EX Plus (Japan 970407)
    + Street Fighter II: The World Warrior (Japan 910522)
    + Manx TT Superbike - DX (Revision D)
    + Tekken Tag Tournament (Japan, TEG2/VER.C1)
    + Street Fighter II': Champion Edition (Hung Hsi, bootleg)
    + Enforce (Japan, Analog Controls)
    + Bubble Bobble II (Ver 0.0J 1993/12/13, prototype)
    + Pipe Dream (Taiwan)
    + Crazy Kong (bootleg on Galaxian hardware, encrypted)
    + Excelsior (set 2)
    + Space Invaders (TV Version, set 2)
    + Puzzle Bang Bang (Korea, version 2.9 / 990108)
    + Turbo Out Run (Japan, Out Run upgrade, FD1094 317-0117)
    + Cotton (set 2, Japan, Rev B, FD1094 317-0179b)
    + Chase Bombers (Japan)
    + New Fantasia (Set 2)
    + Manx TT Superbike - DX (Revision D)
    + Pole Position (World)
    + Ikari 3 (Korea, 8-Way Joystick)
    + Gals Panic 3 (Korea)
    + Punch-Out!! (Japan)
    + Pigskin 621AD (rev 1.1 6/05/90)
    + Jurassic Park (Japan, Rev A, Convertion)
    + Violent Storm (ver EAC)
    + Free Kick (bootleg set 3)
    + Street Fighter II: The World Warrior (Japan 910411)
    + DoDonPachi Dai-Ou-Jou (2002.10.07.Black Ver)
    + Trivia Madness - Series B Question set
    + Arcadia
    + Dragon Gun (Japan)
    + Tetris (Japan, H-System)
    + Guardian Storm (Germany)
    + Super Poker (v100xD03) / Formosa (not working)
    + P-47 - The Freedom Fighter (Japan, Export)
    + Snow Bros. - Nick & Tom (The Winter Bobble hardware bootleg)
    + Mini Boy 7 (set 3)
    + Shanghai 3 (US)
    + Jackal (World, Rotary Joystick)
    + 3 Wonders (bootleg)
    + Street Fighter Zero (Asia 950605)
    + Fighter's History (Japan ver 42-03, DE-0395-1 PCB)
    + Golden Tee 3D Golf (v1.9L)
    + Pit Boss Superstar (9221-12-01)
    + Knights of Valour 2 - Nine Dragons (ver 202)
    + Speed Up (Spanish bootleg of Pole Position)
    + Zombie Raid (US & Japan release versions, prototype PCB)
* Wed Jun 12 2013 gber@opensuse.org
- update to version 0.149
  * new games
    + Top XXI (Version 1.2)
    + Attack Force
    + Mundial/Mondial (Italian/French)
    + Let's Attack Crazy Cross (GV027 Asia 1.10)
    + Crystals Colours (Ver 1.01)
    + Stunt Air (imperfect gfx, sound, colours, need PCB
    measurements)
    + Royale (set 1)
    + Royale (set 2)
    + Videotron Poker (cards selector)
    + Videotron Poker (normal controls)
    + Fruit Land
    + Spooky Night 2nd Edition (Version 2.0.4)
    + Spooky Night (Version 1.0.1)
    + Good Luck II
    + Bases Loaded (Prototype, PlayChoice-10)
    + Sex Appeal (Version 6.02)
    + Caribbean Gold (3VXEC449, USA)
    + Caribbean Gold II (3XF5182H04, USA)
    + Fortune Hunter (2XF5196I01, USA)
    + Fortune Hunter (2XF5196I02, USA)
    + Magic Card II (green TAB or Impera board)
    + Magic Card II (blue TAB board, encrypted)
    + Royal Card v2.0 Professional
    + Zenkoku Seifuku Bishoujo Grand Prix Find Love
    + Cool Riders
    + Williams 6-in-1 Multigame
    + Dream Ball
    + PoPo Bear
    + Stadium Hero '96
    + Bonne Chance! (French/English)
    + Brixian
    + Number One
    + New York Joker
  * new clones
    + Commando Bootleg 2
    + Cresta Mundo (Laguna S.A. Spanish Moon Cresta bootleg)
    + WWF: Wrestlemania (rev 1.1 07/11/95)
    + Scramble (Reben S.A. Spanish bootleg)
    + Sky Soldiers (bootleg)
    + Galaxian (bootleg, set 2)
    + Nudge Double Up (JPM SRU)
    + Unknown SRU Game
    + Borderline (Tranquilizer Gun conversion) (not working, bad
    ROM)
    + Mysterious Stones - Dr. Kick in Adventure (Itisa PCB)
    + Aerolitos (Spanish bootleg of Asteroids)
    + Satan of Saturn (Inder S.A., bootleg)
    + Suzuka 8 Hours 2 (Japan)
    + TeddyBoy Blues (Old Ver. bootleg)
    + Car Action (set 2)
    + Space Chaser (set 4)
    + Mission Craft (version 2.7)
    + Crazy Climber (Spanish, Operamatic bootleg)
    + Impacto (Billport S.A., Spanish bootleg of Scramble)
    + Scramble (Petaco S.A., Spanish bootleg)
    + Ave Fenix (Spanish bootleg of Phoenix)
    + Pajaro del Espacio (Spanish bootleg of UniWar S)
    + Battle Zone (bootleg of Mayday)
    + Air Inferno (Japan)
    + Crisis Zone (CSZO4 Ver. A)
    + Crisis Zone (CSZO3 Ver. B, set 2)
    + ThunderJaws (rev 3)
    + Contra (Japan, set 2)
    + 18 Challenge Pro Golf
    + Crush Roller (bootleg set 3)
    + Altered Beast (Datsu bootleg) (not working)
    + The Next Space (set 2)
    + Traverse USA (I.P. - American Top Bootleg)
    + Vastar (set 4)
    + Crazy Climber (Model Racing bootleg)
    + Rally X (Model Racing bootleg
    + Lunar Rescue (Model Racing bootleg) set 2
    + Power Spikes (US)
    + Gals Panic II (English) (uncertain set composition) (not
    working)
    + Pang (bootleg, set 4)
    + Final Fight (bootleg)
    + Magic's 10 (ver. 16.54)
    + New Lucky 8 Lines (set 4, W-4)
    + New Lucky 8 Lines (set 5, W-4, main 40%%, d-up 60%%)
    + New Lucky 8 Lines (set 6, W-4, main 40%%, d-up 60%%)
    + Jack Potten's Poker (set 7, Royale GFX)
    + Atom (bootleg of Bombjack Twin) (not working)
    + Dragon's Lair 2: Time Warp (Euro v3.17)
    + Indiana Jones (JPM) (IMPACT, German set 2)
    + Indian Battle (Brazil)
    + Raiden Fighters (Single Board)
    + Guardian Storm (vertical)
    + Red Fox War Planes II (China, set 2)
    + MotoTour / Zippy Race (Tecfri license)
    + Puck Man (Spanish, 'Made in Greece' bootleg)
    + Ms. Pac-Man ('Made in Greece' bootleg)
    + Pacuman (Spanish bootleg of Puck Man)
    + Moon Cresta (Electrogame S.A. Spanish bootleg)
    + Moon Cresta (Petaco S.A. Spanish bootleg)
    + Galaxian (Recreativos Franco S.A. Spanish bootleg)
    + Phoenix (Spanish bootleg)
    + Ataque Sideral (Spanish bootleg of UniWar S)
    + Bomb Jack (Tecfri, Spain)
    + Le Bagnard (Itisa, Spain)
    + Wing Shooting Championship V1.00
    + D. D. Crew (Japan, 4 Players, FD1094 317-0185)
    + Se Gye Hweng Dan Ultra Champion (Hong Kong)
    + Back Street Soccer (larger ROMs)
    + Knuckle Heads (Japan, Prototype?)
    + Oriental Legend Special / Xi You Shi E Zhuan Super (ver. 103,
    China, Tencent) (unprotected)
    + DoDonPachi II - Bee Storm (various sets)
    + Super Chase - Criminal Termination (World)
    + Arkanoid Returns (Ver 2.02O 1997/02/10)
    + Ball Boy
    + Virus (Dr. Mario prototype, PlayChoice-10)
    + Hit The Six (Project) (set 3)
    + (U.S.) Games V18.5
    + Magic Johnson's Fast Break (Arcadia, V 2.7)
    + Hang-On (older?)
    + Daytona USA Special Edition (Japan, Revision A)
    + Daytona USA (Japan, Turbo hack, set 2)
    + Gaplus (GP2)
    + Side by Side (Ver 2.7 J)
    + Capcom Vs. SNK Millennium Fight 2000 (JPN, USA, EXP, KOR,
    AUS)
    + Raiden Fighters Jet (Single Board, set 1)
    + Motocross Go! (MG1 Ver. A)
    + The Pit Boss (2214-03, U5-1C)
    + Riviera Hi-Score (2131-08, U5-2D)
    + Forgotten Worlds (USA, B-Board 88618B-2, Rev. AA)
    + Galaga 3 (GP3)
    + Motocross Go! (MG1 Ver. A, set 2)
    + Karnov (US, rev 6)
    + Cycle Warriors, set 1
    + Scorpion (set 2)
    + Chinese Hero (older, set 2)
    + Three Wonders (World 910513)
    + Starfighter (Moon Cresta bootleg)
    + Bomb Kick (set 2)
    + Seibu Cup Soccer :Selection: (bootleg, set 3) (NOT WORKING)
    + Martial Champion (ver UAE)
    + Demolition Derby
    + Super Ranger (older)
    + Head On (bootleg, alt maze)
    + WWF WrestleFest (Korea)
    + Pit Boss Megatouch II (9255-10-01 ROG, Standard version)
    + Megatouch III (9255-20-01 ROK, Standard version)
    + Megatouch III (9255-20-01 ROB, Standard version)
    + Megatouch III (9255-20-01 ROA, Standard version)
    + Super Megatouch IV (9255-41-01 ROE, Standard version)
    + Super Megatouch IV (9255-41-01 ROC, Standard version)
    + Starblade (World)
    + Tesorone Dell'Isola (Italy, two sets)
    + Jolly Card (Italian, encrypted bootleg, set 2)
    + Lucky 74 (bootleg, set 2)
    + Vastar (set 3)
    + Wonder Boy in Monster Land (English bootleg set 3)
    + WWF Superstars (bootleg)
    + Jackler (Jungler Bootleg)
    + T.T.Fitter (bootleg of Roundup)
    + Super Pool 99 (Version 0.33)
    + Super Pool 99 (Version 0.26)
    + Street Fighter II': Champion Edition (Dongfang Bubai
    protection, bootleg)
    + Continental Circus (Japan)
    + X-Men (4 Players ver AEA)
    + Demon Front (68k label V103, ROM M103XX 07/05/02) (ARM label
    V103, ROM 07/05/02 S103XX)
    + Knights of Valour: Yi Tong Zhong Yuan
    + Lucky Boom (Hard Times / Hot Mind hardware) (not working)
- build mess and add corresponding subpackages mess and mess-tools
- renamed mame-fix-buildsystem.patch to
  mame-fix-executable-suffix.patch
* Sat Jan 12 2013 gber@opensuse.org
- update to version 0.148
  * many bugfixes and improvements
  * new games
    + Armadillo Racing (AM1 Ver. A)
    + Rise of the Robots (prototype)
    + Riviera Hi-Score (2131-08, U5-4A)
    + Manhattan
    + Grasspin
    + Planet Probe
    + Harem
    + Kkot Bi Nyo Special (Korea)
    + Each Way Shifter (Barcrest?)
    + Lucky Twos
    + Scoop (Peter Simper, prototype?) (MPU3)
    + More Money (VFS) (MPU3)
    + Talk of the Town (MPU3)
    + 3X3 Puzzle
    + 3 On 3 Dunk Madness (US, prototype? 1997/02/04)
    + Spark Man (v2.0, 2 sets)
    + Fighting Fantasy (bootleg with 68705)
    + Bonus Card (Austrian)
    + Claybuster
    + Gun Champ
    + Star Fighter (v1)
    + New clones added
    + Asterock (Videotron bootleg)
    + Jurassic Park (Japan)
    + Dodge City (2131-82, U5-0D)
    + Enforce (World)
    + Sega Bass Fishing Deluxe (Japan)
    + Cruis'n Exotica (version 1.3)
    + F1 Super Lap
    + Turbo Out Run (cockpit, FD1094 317-0106)
    + Little Robin
    + Brick Zone (2 sets)
    + Dodge City (9131-02)
    + Ganbare Jajamaru Saisho wa Goo / Ganbare Jajamaru Hop Step & Jump
    + Draw Poker (Bally, 03-20)
    + Magicball Fighting (Korea)
    + Thrill Drive (JAE, JAB)
    + GTI Club
    + Solar Assault
    + Hang Pilot
    + Sky Destroyer
    + Cycle Maabou
    + Space Invaders / Qix Silver Anniversary Edition
    + Pairs Redemption (V1.0, 10/25/94)
    + Last Survivor
    + Cyber Tank
    + Last Bank
    + Hard Drivin' (cockpit, rev 1)
    + Race Drivin' (cockpit, rev 1)
    + Race Drivin' (cockpit, rev 2)
    + Race Drivin' (cockpit, rev 3)
    + Race Drivin' (cockpit, British, rev 1)
    + Race Drivin' (cockpit, German, rev 2)
    + Fruit Dream
    + Get Rich
    + Mahjong Janshin Plus (Japan)
    + Mahjong Dai Touyouken (Japan)
    + Return Of Sel Jan II (Japan, NM557)
    + Linky Pipe
    + Offroad Challenge
    + Touryuumon
    + Space Invaders Multigame (several versions)
    + Super ABC (Pac-Man multigame kit)
    + Fantasy Zone II (System 16C version)
    + Fishing (DECO Cassette).
    + Flipper Jack
    + Konami Test Board GX800
    + Magical Speed
    + Dragon World 2001
    + Dragon World Pretty Chance
    + Funcube
    + Linky Pipe
    + Racing Beat
    + Chance Thirty Two
    + Chance Kun
    + Bikkuri Card
    + DS Telejan (DECO Cassette)
    + Hyper Bishi Bashi Champ (GQ876 VER. EAA)
    + Hyper Bishi Bashi Champ (GQ876 VER. AAA)
    + Handle Champ (GQ710 VER. JAA)
    + Mahjong Long Hu Zheng Ba 2 (VS221M)
    + Super Stars
    + Funcube 5
    + Dungeon Explorer (Tourvision PCE bootleg)
    + Super Volleyball (Tourvision PCE bootleg)
    + Jue Zhan Tian Huang
    + Golden Arrow (Standard G8-03)
    + Silver Millennium
    + Draw Poker - Joker's Wild (Standard)
    + Draw Poker - Joker's Wild (02-11)
    + Fun River
    + unknown Japanese horse gambling game (preliminary)
    + Janken Man Kattara Ageru
    + Kong (Brazil)
    + Fantastic
    + Witch Up & Down (Export, 6T/12T ver 0.99)
    + Witch Up & Down (Export, 6T/12T ver 1.02)
    + Wild Witch (Export, 6T/12T ver 1.74A)
    + Witch Strike (Export, 6T/12T ver 1.01A)
    + Witch Strike (Export, 6T/12T ver 1.01B)
    + Wild Witch (Export, 6T/12T ver 1.84A)
    + Witch Jack (Export, 6T/12T ver 0.87-89)
    + DoDonPachi II - Bee Storm (Japan, vers. 102,101,100)
    + Lucky Boom
    + Demon Front (PGM cartridge versions)
    + Galaxia
    + Astro Wars
    + Skater (cassette)
    + Super Doubles Tennis (cassette)
    + Casino Poker (Ver PM86LO-35-5, German)
    + Winning Run
    + Oozumou - The Grand Sumo (DECO Cassette)
    + Diet Family
    + Kung-Fu Roushi
    + Winning Run Suzuka Grand Prix
    + Winning Run 91
  * new clones
    + Super Street Fighter II: The Tournament Battle (Hispanic 931005)
    + Star Warrior (Potomac Mortage version of Space Firebird)
    + Survival Arts (Japan)
    + Alien Syndrome (set 7, System 16B, MC-8123B 317-00xx)
    + King Derby (bootleg set 2)
    + Bump 'n' Jump (original Data East USA)
    + Toride II Bok Su Oi Jeon Adauchi Gaiden (Korea)
    + Monza GP (bootleg)
    + Super Cup Finals (Ver 2.2O 1994/01/13)
    + Imola Grand Prix (newer set) (not working)
    + Sprint 2 (color kit, Italy)
    + Penfan Girls - Step1. Mild Mind (set 2)
    + Street Fighter Zero 2 (Japan 960430)
    + Hacher (hack of Win Win Bingo)
    + Moon Crest (Moon Cresta bootleg)
    + Se Gye Hweng Dan Ultra Champion (Korea)
    + Astrians (clone of Swarm)
    + Bomber (bootleg of Scramble)
    + Frogger (Scramble hardware)
    + Ghost Muncher
    + Phoenix (Irecsa / G.G.I Corp, set 4)
    + Pleiads (bootleg set 2)
    + Star Wars (bootleg of Galaxy Wars, set 2)
    + Witch
    + Mechanized Attack (US, Single Player)
    + Mystic Marathon (prototype)
    + Royal Casino (D-2608208A1-1, Larger Board)
    + Royal Casino (D-2608208A1-1, Smaller Board)
    + Street Fighter II': Magic Delta Turbo (bootleg, set 2)
    + Street Fighter II': Champion Edition (M8, bootleg) (not working)
    + Sunset Riders (4 Players ver JAC)
    + Riviera Hi-Score (2131-08, U5-4)
    + Super Earth Invasion (Electrocoin, bootleg)
    + Zero Point (Japan)
    + X-Men: Children of the Atom (Euro 950331)
    + Dragon's Lair 2: Time Warp (Euro v3.19) (not working)
    + Dragon's Lair 2: Time Warp (Spanish v3.19) (not working)
    + Dragon's Lair 2: Time Warp (US v3.18) (not working)
    + Dragon's Lair 2: Time Warp (Euro v3.16) (not working)
    + Dragon's Lair 2: Time Warp (US v3.15) (not working)
    + Dragon's Lair 2: Time Warp (Spanish v3.15) (not working)
    + Dragon's Lair 2: Time Warp (US v3.14) (not working)
    + Dragon's Lair 2: Time Warp (US v3.12) (not working)
    + Dragon's Lair 2: Time Warp (US v3.00) (not working)
    + Dragon's Lair 2: Time Warp (US v2.11) (not working)
    + Carrier Air Wing (bootleg with 2xYM2203 + 2xMSM205 set 2)
    + Space Ace (DL2 Conversion) (Euro v1.3) (not working)
    + Head On (bootleg on dedicated hardware)
    + The Punisher (Hispanic 930422)
    + Space Combat (bootleg of Space Invaders)
    + Scramble (Stern Electronics set 2)
    + Rolling Thunder (rev 2)
    + World Class Bowling (v1.3J, Japan)
    + Space Chaser (set 2)
    + Space Chaser (set 3)
    + Gun Champ (newer, Super Shot hardware)
    + Donkey King
    + Jr. Pac-Man (speedup hack)
    + Super Ranger (NOVA)
    + Magix / Rock (bootleg)
    + Jet Wave (JAB, Japan v1.04)
    + Golden Tee Diamond Edition Tournament (v3.05T ELC)
    + Western Express (Japan, rev 4)
    + Sunset Riders (4 Players ver UAB)
    + Kkot Bi Nyo (Korea)
    + World Class Bowling v1.1
    + Haunted Castle (version E)
    + Jolly Card (Spanish, blue TAB board, encrypted)
    + Triple Punch (set 2)
    + Street Fighter 2 Accelerator! (set 2)
    + Gun Survivor 2 Biohazard: Code Veronica (BHF2 Ver. E)
    + Radirgy (Rev A) (GDL-0032A)
    + Ninja Assault (NJA4 Ver. A)
    + Street Fighter II': Champion Edition (Alpha Magic-F, bootleg) (not working)
    + Street Fighter II: The World Warrior (TAB Austria, bootleg) (set 2) (not working)
    + Street Fighter II: The World Warrior (unknown bootleg) (not working)
    + Winding Heat (AAA, Asia v2.11)
    + Ultra Invaders
    + Marvel Vs. Capcom: Clash of Super Heroes (Japan 980123) (Single PCB)
    + Bagman on Moon Cresta hardware (1984 version)
    + Each Way Nudger (Barcrest?, set 3, version 20?)
    + Knights of Valour Super Heroes / Sangoku Senki Super Heroes (ver. 102, CN)
    + Knights of Valour Super Heroes / Sangoku Senki Super Heroes (ver. 101, CN)
    + Invader's Revenge (3 sets)
    + Megatouch 5 Tournament Edition (9255-70-01 ROC, Standard version)
    + Phoenix (Irecsa / G.G.I Corp, set 3)
    + Rallys (alternate bootleg of Spectar)
    + The Billiards (Video Hustler bootleg) - Set 2
    + Double Axle (US)
    + Angler Dangler
    + Puzzli 2 (ver 100)
    + 4-in-1 MAME bootleg (set 1, ver 3.00)
    + 4-in-1 MAME bootleg (set 2)
    + 19-in-1 MAME bootleg
    + 48-in-1 MAME bootleg (set 2, ver 3.09, alt flash)
    + 60-in-1 MAME bootleg (ver 3.00)
    + Xain'd Sleena (World)
    + WEC Le Mans 24 (set 2)
    + The Speed Rumbler (set 3)
    + Rapid River (prototype)
    + Hang Pilot (ver UAA) (not working)
    + Seibu Cup Soccer (set 3) (not working)
    + Egg Venture (Release 2)
    + The King of Fighters '97 Oroshi Plus 2003 (bootleg)
    + Magic Card II (Nov, Yugoslavian hack)
    + Asterock (Videotron bootleg)
    + Jurassic Park (Japan)
    + Dodge City (2131-82, U5-0D)
    + Enforce (World)
    + Sega Bass Fishing Deluxe (Japan)
    + Cruis'n Exotica (version 1.3)
    + Fantasia (940307 PCB)
    + Superman (US)
    + Ms. Pac-Man Heart Burn
    + F1 Super Lap (World)
    + Thunder Zone (World 4 Player)
    + Dodge City (2131-82, set 2) - Not working
    + Ghosts'n Goblins (prototype)
    + Exciting Soccer (US)
    + GP Rider (Japan)
    + AB Cop (Japan)
    + Ninja Baseball Bat Man II (bootleg/hack)
    + Samba de Amigo (prototype)
    + Blood Storm v1.04
    + JuJu Densetsu (Playmark bootleg)
    + Nandemo Seal Iinkai (Astro Boy ver.)
    + GTI Club (ver UAA)
    + Sega Rally Championship - DX (Revision A)
    + Panic Road (Germany)
    + Parodius DA! (Asia)
    + Megatouch IV (9255-40-01 ROA, Standard version)
    + Olympic Soccer '92 (set 2)
    + Trojan (US set 2)
    + Thunder Zone (Japan)
    + Thunder Zone (Rev 1, World)
    + 777 Heaven (Project) (20p 6GBP Jackpot Version 114) (PROCONN)
    + 777 Heaven (Project) (10p 3GBP Jackpot Version 380) (PROCONN)
    + 777 Heaven (Project) (5p 3GBP Jackpot Version 105) (PROCONN)
    + 777 Heaven (Project) (10GBP Jackpot) (PROCONN)
    + Jumping Jacks (Project) (set 2) (PROCONN)
    + Initial D Arcade Stage Ver. 3 Cycraft Edition (Rev. B) (GDS-0029B)
    + Sega Network Taisen Mahjong MJ 3 (Rev F) (GDX-0017F)
    + Dynamite Duke (Europe set 1)
    + Ninja Baseball Bat Man (World)
    + Cops 'n' Robbers (Bellfruit) (set 2) (Scorpion 1) (NOT WORKING)
    + Last Fortress - Toride (Erotic, Rev A)
    + Note Exchange (Set 2) (Jpm) (MPS) (NOT WORKING)
    + Note Exchange (Set 3) (Jpm) (MPS) (NOT WORKING)
    + Nudge Bonanza Deluxe (Set 2) (Jpm) (MPS) (NOT WORKING)
    + Trick or Treat (Proconn) (NOT WORKING)
    + Action Bank (set 2) (Barcrest) (NOT WORKING)
    + Jumping Pop (set 2)
    + Mortal Kombat II (rev L2.0)
    + Drift Out (Europe)
    + Pipi & Bibis / Whoopee!! (Prototype)
    + Landing Gear (Ver 3.1 O)
    + Tank Battalion (bootleg)
    + Daioh (alternate)
    + Free Kick (NS6201-A 1987.9)
    + Skins Game (1.04)
    + Landing Gear Ver 4.2 J
    + Landing Gear Ver 3.0 J
    + Cruis'n World v2.5
    + Cruis'n World v1.9
    + Dragonball Z (rev B)
    + Deer Hunting USA V1
    + Scud Race Plus
    + Ray Storm (Ver 2.05O)
    + Ray Storm (Ver 2.05A)
    + Fighters' Impact (Ver 2.02A)
    + Super Football Champ (Ver 2.4A)
    + Time Crisis 3 (TST2 Ver. A)
    + Pit Boss Megatouch II (9255-10-02 ROG, Minnesota version)
    + Super Megatouch IV (9255-41-02 ROC, Minnesota version)
    + Mahjong Nenrikishu SP (Japan, V250J)
    + TX-1 (Japan rev. B)
    + War Of The Bugs (US)
    + Raiden (Unknown)
    + War Gods (HD 10/09/1996 - Dual Resolution)
    + War Gods (HD 08/15/1996)
    + Dynamite League (US)
    + Arkanoid (bootleg with MCU, set 2)
    + U.S. Championship V'ball (bootleg of Japan set)
    + Touchmaster 4000 (v6.02 California)
    + Space Ranger
    + Express Raider (Italy)
    + Dynamite Duke (Euro)
    + Battlantis (program code F)
    + Virtua Striker 2 (Step 1.5, older)
    + Nagano Winter Olympics '98 (GX720 JAA)
    + Crisis Zone (CSZO3 Ver. A)
    + Red Barron
    + Bulls Eye Darts (Galaxian conversion)
    + Over Rev (Model 2B, Revision B)
    + Hamburger (DECO Cassette, Japan)
    + Pro Golf (DECO Cassette) (set 2)
    + Super Poker (Version 10.10)
    + Ms. Pac-Man II (bootleg)
    + Ms. Pac-Man II (Orca bootleg set 2)
    + Tecmo Bowl (World, prototype?)
    + Zero Team 2000
    + OutRunners (Japan)
    + Top Racer (bootleg of Driving Force)
    + Gulf Storm (set 2)
    + Erotictac/Tactic (ver 01)
    + Space Firebird (rev. 02-a)
    + Congo Bongo (3 board stack)
    + Mahjong Yoshimoto Gekijou
    + Zoku Mahjong Housoukyoku
    + Moon Cresta (Nichibutsu UK, unencrypted)
    + Red Fox War Planes II (China)
    + Sharpshooter (Rev 1.9)
    + Zeke's Peak
    + Hot Mind (Fit of Fighting Hardware)
    + Rastan (US)
    + Mortal Kombat (Turbo 3.0 08/31/92, hack)
    + Street Fighter EX2 Plus (Hipanic 990611)
    + Intrepid (bootleg)
    + Wonder Boy (set 5, bootleg)
    + Caveman Ninja (bootleg, alt)
    + Wild Witch (Export, 6T/12T ver 1.57-SP)
    + Wild Witch (Export, 6T/12T ver 1.62A)
    + Wild Witch (Export, 6T/12T ver 1.62B)
    + Wild Witch (Export, 6T/12T ver 1.62A alt)
    + Wild Witch (Export, 6T/12T ver 1.62B alt)
    + Wild Witch (Export, 6T/12T ver 1.65A)
    + Wild Witch (Export, 6T/12T ver 1.65A-S)
    + Wild Witch (Export, 6T/12T ver 1.65A-S alt)
    + Wild Witch (Export, 6T/12T ver 1.65A-N)
    + Wild Witch (Export, 6T/12T ver 1.70A beta)
    + Wild Witch (Export, 6T/12T ver 1.70A)
    + Wild Witch (Export, 6T/12T ver 1.70A alt)
    + Wild Witch (Export, 6T/12T ver 1.74A-SP-BELG)
    + Wild Witch (Export, 6T/12T ver 1.74A)
    + Wild Witch (Export, 6T/12T ver 1.74A alt)
    + Wild Witch (Export, 6B/12B ver 1.75A-E)
    + Wild Witch (Export, 6T/12T ver 1.76A)
    + Wild Witch (Export, 6T/12T ver 1.77A)
    + Wild Witch (Export, 6T/12T ver 1.79A)
    + Wild Witch (Export, 6T/12T ver 1.83A)
    + Big Striker (bootleg w/Italian teams)
    + Fighting Soccer (Joystick hack bootleg, alt)
    + Witch Jackpot (Export, 6T/12T ver 0.25)
    + Witch Jack (Export, 6T/12T ver 0.40)
    + Witch Jack (Export, 6T/12T ver 0.62)
    + Witch Jack (Export, 6T/12T ver 0.64)
    + Witch Jack (Export, 6T/12T ver 0.65)
    + Witch Jack (Export, 6T/12T ver 0.70S)
    + Witch Jack (Export, 6T/12T ver 0.70P)
    + Witch Jack (Export, 6T/12T ver 0.87)
    + Witch Jack (Export, 6T/12T ver 0.87-88)
    + S.V.G. - Spectral vs Generation (M68k label V100JP) (ARM label V100JP) (JAMMA PCB)
    + Demon Front (68k label V107, ROM M107KR 11/03/03) (ARM label V107, ROM
    + The Gladiator - Road of the Sword / Shen Jian (M68k label V100) (ARM
    + Witch Up & Down (Export, 6T/12T ver 0.99, set 2)
    + Witch Up & Down (Export, 6T/12T ver 0.99, set 3)
    + Witch Up & Down (Export, 6T/12T ver 0.99T)
    + Falcons Wild - World Wide Poker (Video Klein, set 2)
    + 1945 2 - Battle Garegga Chinese hack
    + Bobble Bobble (set 2)
    + Dribbling (bootleg, Brazil)
    + Galactic Empire
    + Polaris (Brazil)
    + Dragonninja (bootleg)
    + Rastan (World set 2)
    + 1941: Counter Attack (World 900227)
    + Final Fight (World, set 2)
    + Forgotten Worlds (USA, B-Board 88618B-2, Rev. C)
    + Street Fighter II: The World Warrior (USA 920522, Rev. G)
    + Virtua Cop (Revision A)
    + Super Street Fighter II X: Grand Master Challenge (Japan 940223 rent version)
    + Vampire Hunter: Darkstalkers' Revenge (Japan 950307 stop version)
    + JoJo's Venture (990128)
    + Pit Boss Megatouch II (9255-10-06 ROE, California version)
    + Megatouch IV (9255-40-01 RO, Standard version)
    + Super Chase - Criminal Termination (Japan)
    + Deer Hunting USA V3
    + Battle Gear 2 (2.01J)
    + Soul Calibur III (SC31002-NA-NA)
    + Tekken 4 (TEF1 Ver. C)
    + Street Fighter II': Champion Edition (Japan 920803)
    + Raiden Fighters Jet (Taiwan)
    + Arkanoid - Revenge of DOH (Japan bootleg)
    + Dynablaster / Bomber Man (bootleg, alt)
    + Caveman Ninja (alternate)
    + Altered Beast (FD1094 317-0069)
    + PuzzLoop 2 (Japan 010226)
    + Street Fighter II': Champion Edition (Japan 920322)
    + Mortal Kombat (Yawdim bootleg - Set 2)
    + Space Invaders Part II (Brazil)
    + Print Club 2 Earth Limited Kobe (Print Club Custom) (J 970808 V1.000)
    + Eyes (bootleg set)
    + JoJo's Bizarre Adventure (990927)
    + Wyvern Wings (alt)
    + Dynamite Baseball
* Sun Mar  4 2012 gber@opensuse.org
- update to version 0.145
  * many bugfixes and improvements
  * new games
    + Street Games II
    + Boong-Ga Boong-Ga (Spank'em!)
    + Steal See (& Get Land)
    + Toy Land Adventure
    + Quizard 1.8
    + Quizard 2.3
    + Forte Card (Spanish)
    + Itazura Tenshi
    + Fruit Bonus Deluxe
    + Birdiy
    + Keith Courage In Alpha Zones
    + Alien Crush
    + Pac-Land (United Amusements PC Engine)
  * new clones
    + Print Club 2 Felix The Cat (Rev. A)
    + Print Club 2 '98 Spring Ver
    + Hyperspace (bootleg of Asteroids)
    + Tekken Tag Tournament (Asia, TEG2/VER.C1, set 1)
    + X-Men (4 Players ver ADA)
    + Print Club Goukakenran (J 991104 V1.000)
    + Print Club Olive (J 980717 V1.000)
    + Print Club 2 '98 Autumn Ver (J 980827 V1.000)
    + Print Club Kome Kome Club (J 970203 V1.000)
    + Ultimate Arctic Thunder
    + Dumped HDD for Photo Play 2000 v2.01
    + Flying Shark (bootleg, set 2)
    + Arcana Heart
    + Rapid Fire v1.1 (Build 238)
    + Gals Panic S - Extra Edition (Europe)
    + Western Gun Part II
    + Rival Schools: United By Fate (Euro 971117)
    + Street Fighter III 3rd Strike: Fight for the Future (Euro 990608)
    + Street Fighter III 3rd Strike: Fight for the Future (Euro 990512)
    + Exzisus (TAD License)
    + Guzzler (Swimmer Conversion)
    + Warriors of Fate 921031 ETC
    + Space Gun (Japan)
    + Space Gun (US)
    + Pro Soccer (cassette, Japan)
    + Crock-Man
    + The Ninja Warriors (US)
    + Gun Hard (Japan)
    + Gals Panic 3 (Euro)
    + Battle Balls (Asia, earlier)
    + Pepper II - Version 7
    + J. J. Squawkers (bootleg, Blandia Conversion)
    + World Beach Volleyball (set 3)
    + Pang! 3 (Euro 950511)
    + B.Rap Boys Special (US)
    + Forte Card (Spanish)
    + Spiker (2 sets)
* Sun Nov 27 2011 gber@opensuse.org
- update to version 0.144
  * many bugfixes and improvements
  * new games
    + Dirt Dash
    + Galaxy Game
    + Waku Waku Doubutsu Land TonTon
    + Kasino '89
    + Novo Play Multi Card / Club Card
    + PEPSI Man
    + Uchuu Tokkyuu Medalian
    + Funcube 3
    + FamicomBox
    + Bingo (set 1)
    + Bingo (set 2)
    + 30 Test (Remake)
    + Candy Candy
    + Deluxe 5
    + PEPSI Man
    + Super Shot
    + Umi de Poker / Marine Paradise
    + Slot Poker Saiyuki
    + Ridge Racer 2
    + Free Kick
    + Mahjong Tian Jiang Shen Bing (V137C)
    + Densha de GO!
    + Densha de GO! 2
    + Landing Gear
    + Penky
    + Enchanted Forest (12XF528902, US)
    + Arctic Wins (4XF5227H03, US)
    + GP Rider (set 2, World, FD1094 317-0163)
    + Hanafuda Hana Gokou Bangaihen
  * new clones
    + King of the Monsters 2 - The Next Thing (prototype)
    + Alien Front (Rev T)
    + House of the Dead 2 (prototype)
    + 18 Wheeler (Rev. A)
    + Zero Team (set 5, Korea, Dream Soft license)
    + Battle Shark (Japan, Joystick)
    + Crash (bootleg of Head On)
    + Gunbuster (US)
    + Mustafa and 40 Thieves (Bootleg)
    + Flyball (rev 2)
    + Bad Lands (bootleg, alternate)
    + Witch Card (Video Klein CPU box, set 2)
    + Alpha Mission 2 (prototype)
    + Burning Fight (prototype)
    + Jungle King (alternate sound)
    + Zero Gunner (Japan, Model 2A)
    + Last Bronx (USA, Revision A)
    + Viper Phase 1 (USA, New Version, set 2)
    + Vigilante (US) - Rev. G
    + Cruis'n Exotica v1.0
    + NBA Jam T.E. Nani Edition (rev 5.2 8/11/95)
    + Muroge Monaco (set 3)
    + Butasan - Pig's & Bomber's (Japan, English)
    + Aqua Jack (US)
    + Ikari 3 (Japan)
    + Exvania (World)
    + 1943: Midway Kaisen (Japan, Rev B)
    + Rad Rally (Japan)
    + The King of Fighters '97 (Korean release)
    + Phoenix (Irecsa / G.G.I Corp - set 2)
    + Rescue (bootleg) (not working)
    + The End (bootleg) (not working)
    + Missile Combat (Sidam bootleg) (not working)
    + Biomechanical Toy (Ver. 1.0.1884)
    + Shocking (Korea)
    + Puzz Loop (Europe, v0.94)
    + Donkey King Jr. (bootleg of Donkey Kong Jr.)
    + Sauro (Philko license)
    + Raiders (Rev.3)
    + Magic Card Export 94
    + Sagaia (dual screen) (World)
    + Mortal Kombat (Nifty Kombo, hack)
    + Mortal Kombat (Nifty Kombo 666, hack)
    + Savanna (Jungler bootleg)
    + Pit Boss Megatouch II (9255-10-01 ROD, Standard version)
    + Galivan - Cosmo Police (12/26/1985)
    + Missile Command (rev 3)
* Fri Aug  5 2011 gber@opensuse.org
- update to version 0.143
  * many bugfixes and improvements
  * new games
    + Warp Speed (prototype)
    + Mortal Kombat 4 (version 1.0)
    + Baryon Future Assault
    + Reality Tennis
    + Fruit Bonus '06 - 10th anniversary
    + Super Ball (Version 1.3)
    + Doraemon no Eawase Montage (prototype)
    + Chequered Flag
    + Super Wing
    + Mighty Guy
    + Major Poker (v2.0)
    + Witch Royal (Export version 2.1)
    + Water-Nymph (Ver. 1.4)
  * new clones
    + Terra Force (Japan)
    + Street Fighter II: The World Warrior (USA 910306)
    + Final Fight (USA, set 2)
    + Leader Board (Arcadia, set 3)
    + OnePlay Version 2.20 bios
    + Heated Barrel (Electronic Devices license)
    + Tekken 3 (Japan, TET1/VER.A)
    + Tekken 3 (Asia, TET2/VER.E1)
    + The Real Ghostbusters (US 2 Players, revision 2)
    + Dream Crown (Set 2)
    + Harley Davidson (Rev.B)
    + Motocross Go (MG2 Ver.A)
    + Nouryoku Koujou Iinkai (prototype)
    + Pit Boss Superstar (9221-10-00A)
    + Champion Poker (v100)
    + Gunbarl (Japan, GNB4/VER.A)
    + Amidar (Konami/1982)
    + Witch Card (German, WC3050, 27-4-94)
    + Tekken 2 (TES3 VER.D)
    + Soul Edge (SO2/VER.A)
    + Soul Calibur (SOC13 VER.C)
    + Tekken Tag (TEG2 VER.C1)
    + Street Fighter III: New Generation (Hispanic 970204)
* Mon Apr 11 2011 gber@opensuse.org
- update to version 0.142
  * many bugfixes and improvements
  * implemented "-watchdog" option for SDLMame
  * copied the "-bench" option from win32 to sdl
  * added "-syncrefresh" option which in combination with
    "-waitsync" limits the game speed to the video refresh rate
  * new games
    + Mr. Kicker
    + X-Plan
    + Penfan Girls
    + Witch Card (Video Klein CPU box)
    + Jolli Witch (Export, 6T/12T ver 1.57D)
    + Wild Witch (Export, 6T/12T ver 1.74A)
    + Express Card / Top Card
    + Magic Train
    + X-Train
    + Music Sort (ver 2.02, English)
    + 18 Wheeler
    + Animal Catch
    + Itazura Monkey
    + California Games (Mega-Tech)
    + Hae Hae Ka Ka Ka
    + Pye-nage Taikai
    + Taihou de Doboon
    + Dance Dance Revolution 2nd Mix - Link Ver (GE885 VER. JAB)
    + Guilty Gear X 1.5
    + Brasil 86
    + Brasil 87
    + Brasil 89 (set 2)
    + Brasil 93
    + Reel'N Quake
    + Ruleta RE-800 (earlier)
    + Ruleta RE-800 (v1.0)
    + Ruleta RE-800 (v3.0)
    + Galactica
    + Lucky Roulette (6-players, Spanish)
    + Super Twenty One
    + Ruleta RCI (6-players, Spanish)
    + Winners Circle 82
    + Winners Circle (81, 28*28 PCB)
    + Winners Circle (81, 18*22 PCB)
  * new clones
    + Sega Touring Car Championship (Newer)
    + Sega Touring Car Championship (Unknown Revision)
    + Mahjong Man Guan Da Heng (Taiwan, V125T1)
    + Zero Team Suicide Revival Kit
    + Bombjack Twin (prototype? with adult pictures)
    + Sexy Parodius (ver AAA)
    + Ring of Destruction: Slammasters II (Asia 940831)
    + Street Fighter Alpha 2 (USA 960430)
    + Gekirindan (Ver 2.30 1995/09/21)
    + 1943: Battle of Midway (bootleg, hack of Japan set)
    + Scramble (bootleg?)
    + Zero Target (World, CW)
    + Space Bomber
    + Top Skater (Japan)
    + Prehistoric Isle in 1930 (Korea)
    + Zero Hour (set 2)
    + Hidden Catch 2 (pcb ver 1.00) (Kor/Eng/Jpn/Chi)
    + Tenchi wo Kurau (Japan Resale Ver.)
    + Red Earth / Warzard (961023)
    + Double Dribble (prototype?)
    + Tetris Plus 2 (Japan, V2.1)
    + Violent Storm (ver AAB)
    + Black Tiger (older)
    + Whirlwind (LG-3)
    + Real Mahjong Gold Yumehai / Super Real Mahjong GOLD part.2
    (BET version of Super Real Mahjong Part 3)
    + Video Hustler (Dynamo Games)
    + Hot Memory (V1.1, Germany)
    + Pigskin 621AD (rev 2.0 7/06/90)
    + Wild West C.O.W.-Boys of Moo Mesa (ver UA, set 1)
    + Bubble Pong Pong (clone of Miss Bubble 2)
    + Knights of Valour 2 / Sangoku Senki 2 (ver. 101, 101, 100HK)
    + Monopoly (3.01)
    + Monopoly (2.51)
    + Monopoly (2.33)
    + Austin Powers (3.01)
    + Austin Powers (3.00)
    + Austin Powers (2.01)
    + Maverick (Display Rev. 4.00)
    + Cut The Cheese (Redemption)[destruk]
    + Cut The Cheese Deluxe (Redemption)[destruk]
    + Night Rider (rev. 21)
    + Eight Ball Deluxe (rev. 14)
    + Lord Of The Rings, The (9,8,7,401)(En,Sp,Ger,Fr,It)
    + Elvis (4.00,3.03,3.02) (En,Sp,It,Fr,Ger)
    + Ripley's Believe It or Not! (3.10,3.02,3.00) (En,Sp,It,Fr,Ger)
    + Sharkey's Shootout (2.07) (En,Ger,Fr,It)
    + Terminator 3: Rise of the Machines (2.05) (En,Sp,Fr,It)
    + Playboy (3.03,3.00) (En,Sp,Fr,It,Ger)
    + Roller Coaster Tycoon (7.01,4.00) (En,Sp,Fr,It,Ger)
    + Big Twin (No Girls Conversion)
    + Super Star Crest
    + 1941: Counter Attack (USA 900227)
    + Simpsons Pinball Party (4.00,2.04) (En,Sp,Fr,It,Ger)
    + Grand Prix (4.00,3.40,3.01) (En,Sp,Fr,It,Ger)
    + Nascar (4.00,3.50,3.40, 3.01) (En,Sp)
    + Sopranos (3.00, 2.04, 1.07) (En,Sp,Fr,It,Ger)
    + High Roller Casino (2.10)
    + Playboy (4.01,2.03) (En,Sp,Fr,It,Ger)
    + Roller Coaster Tycoon (6.00) (En,Sp,Fr,It)
    + Street Fighter Alpha 3 (Hispanic 980904)
    + Empire City: 1931 (Italy)
    + Thunder & Lightning (bootleg with Tetris sound)
    + The Pit (US, set 2)
    + Terra Cresta (newer PCB)
    + Speak & Rescue (bootleg)
    + Heavy Unit -U.S.A. Version-
    + Ropeman (bootleg of Roc'n Rope)
    + Fashion Gambler (Set 2)
    + AAcrobatic Dog-Fight (USA)
- specfile cleanup
* Fri Jan 14 2011 guido+packman@berhoerster.name
- update to 0.141
  * added new option -uifont to specify the UI font
  * many bugfixes and improvements
  * new games
    + Heavy Unit
    + Poizone
    + Silver Game
    + Jack Potten's Poker (NGold) (3 sets)
    + Bullet
    + Rumba Lumber
    + Deluxe Trivia ? Whiz (Edition 5)
    + Denjin Makai
    + Balloon & Balloon (BnB Arcade)
    + Happy Tour
    + Dai San Wakusei Meteor
    + Pac-Slot
    + Super Double (French)
    + Pit Boss Megatouch II
    + Royal Card (TAB original)
    + Janputer Special
    + Bygone
  * new clones
    + Multi Champ Deluxe (ver. 1114, 14/11/1999) (not working)
    + Gran Tesoro? / Play 2000 (v4.0) (Italy) (not working)
    + Raiden (US, set 2)
    + Golden Tee Golf (Trackball, v2.0)
    + Relief Pitcher (set 2, 26 Apr 1992 / 08 Apr 1992)
    + G.I. Joe (World, EB8, prototype?)
    + Space Firebird (2 sets)
    + World Class Bowling v1.4
    + Ataxx (Europe)
    + Gals Ds - Three Dealers Casino House (bootleg?)
    + Gyruss (bootleg)
    + Parodius DA! (World, set 2)
    + Gals Panic 2 (Italy)
    + Quester Special Edition (Japan)
    + Tic Tac Trivia (Vertical)
    + Raiden II (set 7, US Fabtek) (not working)
    + The King of Dragons (World 910805)
    + Mega Man: The Power Battle (CPS1, USA 951006)
    + Street Fighter II: The World Warrior (World 910228)
    + Super Space Invaders '91
    + Megatouch III (9255-20-06 ROD, California version)
    + Megatouch IV (9255-40-01 ROB, Standard version)
    + Super Megatouch IV (9255-41-01 ROG, Standard version)
    + Mortal Kombat (prototype, rev 4.0 07/14/92)
    + Mortal Kombat II (rev L1.1)
    + Buccaneer
    + Jungle Boy
    + Bee Storm - DoDonpachi II (ver 101) (not working)
    + Sunset Riders 2 (bootleg)
    + Buck Rogers: Planet of Zoom (not encrypted, set 2)
    + Time Killers (v1.21)
    + Dogyuun (test location version)
    + Pit Boss Megatouch II 9255-10-01 R0E
    + JoJo's Venture (USA 990108)
    + JoJo's Venture (USA 981202)
    + Moon Shuttle (US? set 2)
    + Mega Double Poker (conversion kit, set 2)
    + Mahjong Neruton Haikujiradan (Japan, Rev. A?)
* Fri Dec 24 2010 guido+packman@berhoerster.name
- update to 0.140
  * many bugfixes and improvements
  * new games
    + Devil Island (2 sets)
    + Tetris / Bloxeed (Korean System 16 bootleg) (ISG Selection
    Master Type 2006)
    + Mallet Madness v2.1
    + Piccolo Poker 100
    + Witch Card (Falcon, enhanced sound)
    + Witch Card (German, set 3, alt gfx)
    + Witch Game (Video Klein)
    + Falcons Wild - Wild Card 1991 (TVG)
    + Falcons Wild - World Wide Poker (Video Klein)
    + Victor 6
    + Quizard 1.7
    + Quizard 1.2
    + Quizard 2.2
    + Shinobi / FZ-2006 (Korean System 16 bootleg) (ISG Selection
    Master Type 2006)
    + Poker Master (Tony-Poker V3.A, hack?)
    + Raiden Fighters (Asia?, Metrotainment license)
    + Genie
    + Doki Doki Idol Star Seeker
    + 3 Bags Full - 5VXFC790 (Victorian)
    + Cal Omega - Game 8.0 (Arcade Black Jack)
    + Cal Omega - Game 24.0 (Gaming Draw Poker, hold)
    + Fire Trap (Japan)
    + Royal Card (Nichibutsu)
    + Pacman - 25th Anniversary Edition (V2.0)
    + The Last Starfighter (prototype)
    + Air Race (prototype)
  * new clones
    + Streaking (set 2)
    + Sea Wolf (older?)
    + Gun Fight (older?)
    + Puckman Pockimon (set 2)
    + Hit Me
    + X-Men: Children of the Atom (Asia 950105)
    + Final Lap 3 (Japan - Rev C)
    + Omega Race (set 2)
    + Star Raker
    + Vigilante (World, set 2)
    + Sega Rally Championship (Revision B)
    + Touchmaster 2000 Plus (v4.63 Standard)
    + Touchmaster 4000 (v6.01 Standard)
    + Pioneer Balloon (Rock-Ola license)
    + Legion (bootleg of Legend)
    + Eco Fighters (Phoenix Edition)
    + Knights of the Round (Japan 911127, B-Board 89625B-1)
    + The King of Dragons (Japan 910805, B-Board 89625B-1)
    + Street Fighter II': Champion Edition (World 920513)
    + Willow (Japan, Japanese)
    + Yie Ar Kung-Fu (GX361 conversion)
    + Super Poker (Version 10.15S)
    + Clash-Road (Data East license)
    + Quizard v1.2
    + Quizard Rainbow 4.2
    + Super Megatouch IV Turnier Version (9255-51-50 ROA,
    Bi-Lingual ENG/GER version)
    + Megatouch 5 Turnier Version (9255-70-50 RON, Bi-Lingual
    ENG/GER version)
    + Knights of the Round (Japan 911127, 91634B-2 B-Board)
    + Area 88 (Japan Resale Ver.)
    + Ms. Pac-Man/Galaga - 20th Anniversary Class of 1981 Reunion
    (V1.00)
    + Ms. Pac-Man/Galaga - 20th Anniversary Class of 1981 Reunion
    (V1.03)
* Sat Jul 31 2010 guido+packman@berhoerster.name
- specfile cleaned up
- update to version 0.139
- dropped Debian manpages, now included
* Fri Mar 12 2010 guido+packman@berhoerster.name
- initial packaging of mame
